==> haskell-dependent-sum-template-0.1.1.1-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum-template
version:              0.1.1.1
visibility:           public
id:                   dependent-sum-template-0.1.1.1-9V4wWd2l2Doqi8Lwl21pJ
key:                  dependent-sum-template-0.1.1.1-9V4wWd2l2Doqi8Lwl21pJ
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  a121dbb8954c3def370afe1fec1eddf0
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/dependent-sum-template-0.1.1.1

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/dependent-sum-template-0.1.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.1.1.1-9V4wWd2l2Doqi8Lwl21pJ
depends:
    base-4.15.1.0 dependent-sum-0.7.2.0-99GZdQFXL7X8CQTtOrBD8X
    template-haskell-2.17.0.0
    th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp
    th-extras-0.0.0.6-EEs5JOGg7884FiIbUF9u2f

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-template-0.1.1.1-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum-template
version:              0.1.1.1
visibility:           public
id:                   dependent-sum-template-0.1.1.1-6F1X4O6FT8wBYzynjhKIXw
key:                  dependent-sum-template-0.1.1.1-6F1X4O6FT8wBYzynjhKIXw
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  fbe603e6abfea74d441a28cc99718613
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/dependent-sum-template-0.1.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.1.1.1-6F1X4O6FT8wBYzynjhKIXw
depends:
    base-4.16.4.0 dependent-sum-0.7.2.0-IUWYcQgTXgZG92faVIEnNQ
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-extras-0.0.0.8-4HdejrriKyzHoCvuWPsQ8a

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
